==> ejc-scene-impl-3.0.0-20211025.084927-63-sources.jar: com/ejianc/business/scene/service/CheckMessageService.java <==
package com.ejianc.business.scene.service;

import com.alibaba.fastjson.JSONObject;
import com.ejianc.business.scene.util.NoticeEnum;
import com.ejianc.business.scene.vo.SceneCheckVO;
import com.ejianc.foundation.message.api.IPushMessageApi;
import com.ejianc.foundation.message.vo.PushMsgParameter;
import com.ejianc.framework.core.context.InvocationInfoProxy;
import com.ejianc.framework.core.response.CommonResponse;
import org.apache.commons.lang3.StringUtils;
import org.slf4j.Logger;
import org.slf4j.LoggerFactory;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.beans.factory.annotation.Value;
import org.springframework.stereotype.Service;

import java.text.SimpleDateFormat;
import java.util.ArrayList;
import java.util.Date;
import java.util.HashMap;
import java.util.List;

/**
 * @author songlx
 * @version 1.0
 * @description: 微信公众号消息通知
 * @date 2021/10/20
 */
@Service
public class CheckMessageService {

    private final Logger logger = LoggerFactory.getLogger(getClass());


    @Value("${common.env.base-host}")
    private String baseHost;

    @Value("${weixin_template.check_id}")
    private String weixinCheckTemplateId;

    @Autowired
    private IPushMessageApi pushMessageApi;


    public CommonResponse<String> sendMsg(SceneCheckVO checkVO, String[] receivers, NoticeEnum notice) {
        if (checkVO != null) {
            if (StringUtils.isNotBlank(weixinCheckTemplateId)) {
                HashMap<String, String> keyMap = new HashMap<>();
                keyMap.put("#NUM#", checkVO.getReviewedNum() != null ? String.valueOf(checkVO.getReviewedNum()) : null);
                keyMap.put("#BILLCODE#", checkVO.getBillCode());
                keyMap.put("#CHECKNAME#", checkVO.getCheckName());
                keyMap.put("#ID#", String.valueOf(checkVO.getReviewedNum()));
                keyMap.put("#BASEHOST#", baseHost);
                NoticeEnum.instance(notice, keyMap);
                PushMsgParameter parameter = new PushMsgParameter();
                List<String> channel = new ArrayList<>();
                // 微信公众号消息
                channel.add(PushMsgParameter.CHANNEL_TYPE_WEIXIN);
                JSONObject weixinParams = new JSONObject();
                weixinParams.put("template_id", weixinCheckTemplateId);
                JSONObject wxparams = new JSONObject();
                wxparams.put("first", notice.getContent());
                wxparams.put("keyword1", notice.getKey1());
                wxparams.put("keyword2", new SimpleDateFormat("yyyy-MM-dd HH:mm:ss").format(new Date()));
                weixinParams.put("data", wxparams);
                weixinParams.put("url", (notice.getUrl() + "&openid={openid}"));
                parameter.setWeixinParams(weixinParams);
                parameter.setReceivers(receivers);// 收信人
                parameter.setChannel(channel.toArray(new String[channel.size()]));// 消息类型
                parameter.setMsgType("notice");
                parameter.setSubject(notice.getSubject());// 标题
                parameter.setContent(notice.getContent());// 内容
                parameter.setTenantId(InvocationInfoProxy.getTenantid().toString());
                parameter.setSendUserId(InvocationInfoProxy.getUserid());
                try {
                    CommonResponse<String> result = pushMessageApi.pushMessage(parameter);
                    if (result.isSuccess()) {
                        logger.error("消息发送成功---------------->" + result.getMsg());
                    } else {
                        logger.error("消息发送失败---------------->" + result.getMsg());
                    }
                } catch (Exception e) {
                    logger.error("调用消息中心RPC服务异常--------------" + e);
                }
            } else {
                logger.info("未配置微信公众号模板，故不发微信公众号消息");
            }
        }
        return CommonResponse.success();
    }

    ;


}

==> ejc-scene-impl-3.0.0-20211027.020818-74-sources.jar: com/ejianc/business/scene/service/CheckMessageService.java <==
package com.ejianc.business.scene.service;

import com.alibaba.fastjson.JSONObject;
import com.ejianc.business.scene.util.NoticeEnum;
import com.ejianc.business.scene.vo.SceneCheckVO;
import com.ejianc.foundation.message.api.IPushMessageApi;
import com.ejianc.foundation.message.vo.PushMsgParameter;
import com.ejianc.framework.core.context.InvocationInfoProxy;
import com.ejianc.framework.core.response.CommonResponse;
import org.apache.commons.lang3.StringUtils;
import org.slf4j.Logger;
import org.slf4j.LoggerFactory;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.beans.factory.annotation.Value;
import org.springframework.stereotype.Service;

import java.text.SimpleDateFormat;
import java.util.ArrayList;
import java.util.Date;
import java.util.HashMap;
import java.util.List;

/**
 * @author songlx
 * @version 1.0
 * @description: 微信公众号消息通知
 * @date 2021/10/20
 */
@Service
public class CheckMessageService {

    private final Logger logger = LoggerFactory.getLogger(getClass());


    @Value("${common.env.base-host}")
    private String baseHost;

    @Value("${weixin_template.check_id}")
    private String weixinCheckTemplateId;

    @Autowired
    private IPushMessageApi pushMessageApi;


    public CommonResponse<String> sendMsg(SceneCheckVO checkVO, String[] receivers, NoticeEnum notice) {
        if (checkVO != null) {
            PushMsgParameter parameter = new PushMsgParameter();
            List<String> channel = new ArrayList<>();
            channel.add(PushMsgParameter.CHANNEL_TYPE_WEIXIN);
            channel.add(PushMsgParameter.CHANNEL_TYPE_SYS);
            if (StringUtils.isNotBlank(weixinCheckTemplateId)) {
                HashMap<String, String> keyMap = new HashMap<>();
                keyMap.put("#NUM#", checkVO.getReviewedNum() != null ? String.valueOf(checkVO.getReviewedNum()) : null);
                keyMap.put("#BILLCODE#", checkVO.getBillCode());
                keyMap.put("#CHECKNAME#", checkVO.getCheckName());
                keyMap.put("#ID#", String.valueOf(checkVO.getReviewedNum()));
                keyMap.put("#BASEHOST#", baseHost);
                NoticeEnum.instance(notice, keyMap);

                // 微信公众号消息
                JSONObject weixinParams = new JSONObject();
                weixinParams.put("template_id", weixinCheckTemplateId);
                JSONObject wxparams = new JSONObject();
                wxparams.put("first", notice.getContent());
                wxparams.put("keyword1", notice.getKey1());
                wxparams.put("keyword2", new SimpleDateFormat("yyyy-MM-dd HH:mm:ss").format(new Date()));
                weixinParams.put("data", wxparams);
                weixinParams.put("url", (notice.getUrl() + "&openid={openid}"));
                parameter.setWeixinParams(weixinParams);

            } else {
                logger.info("未配置微信公众号模板，故不发微信公众号消息");
            }

            parameter.setReceivers(receivers);// 收信人
            parameter.setChannel(channel.toArray(new String[channel.size()]));// 消息类型
            parameter.setMsgType("notice");
            parameter.setSubject(notice.getSubject());// 标题
            parameter.setContent(notice.getPcContent());// 内容
            parameter.setTenantId(InvocationInfoProxy.getTenantid().toString());
            parameter.setSendUserId(InvocationInfoProxy.getUserid());
            try {
                CommonResponse<String> result = pushMessageApi.pushMessage(parameter);
                if (result.isSuccess()) {
                    logger.error("消息发送成功---------------->" + result.getMsg());
                } else {
                    logger.error("消息发送失败---------------->" + result.getMsg());
                }
            } catch (Exception e) {
                logger.error("调用消息中心RPC服务异常--------------" + e);
            }
        }
        return CommonResponse.success();
    }

    ;


}
